__all__ = [
    'SegmentationRASA',
]
import crowdkit.aggregation.base_aggregator
import numpy
import pandas.core.frame


class SegmentationRASA(crowdkit.aggregation.base_aggregator.BaseAggregator):
    """Segmentation RASA - chooses a pixel if sum of weighted votes of each performers' more than 0.5.
    Algorithm works iteratively, at each step, the performers are reweighted in proportion to their distances
    to the current answer estimation. The distance is considered as 1-iou. Modification of the RASA method for texts.

    Jiyi Li. 2019.
    A Dataset of Crowdsourced Word Sequences: Collections and Answer Aggregation for Ground Truth Creation.
    Proceedings of the First Workshop on Aggregating and Analysing Crowdsourced Annotations for NLP,
    pages 24–28 Hong Kong, China, November 3, 2019.
    http://doi.org/10.18653/v1/D19-5904
    Attributes:
        segmentations_ (ndarray): Tasks' segmentations
            A pandas.Series indexed by `task` such that `labels.loc[task]`
            is the tasks's aggregated segmentation.
    """

    def fit(self, data: pandas.core.frame.DataFrame) -> 'SegmentationRASA':
        """Args:
            data (DataFrame): Performers' segmentations
                A pandas.DataFrame containing `performer`, `task` and `segmentation` columns'.

        Returns:
            SegmentationRASA: self
        """
        ...

    def fit_predict(self, data: pandas.core.frame.DataFrame) -> numpy.ndarray:
        """Args:
            data (DataFrame): Performers' segmentations
                A pandas.DataFrame containing `performer`, `task` and `segmentation` columns'.

        Returns:
            ndarray: Tasks' segmentations
                A pandas.Series indexed by `task` such that `labels.loc[task]`
                is the tasks's aggregated segmentation.
        """
        ...

    def __init__(self, n_iter: int = 10) -> None:
        """Method generated by attrs for class SegmentationRASA.
        """
        ...

    n_iter: int
    segmentations_: numpy.ndarray
